@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2024 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.57;
+use warnings;
+use Object::Pad 0.800;
 
-package Tangence::Compiler::Parser 0.29;
+package Tangence::Compiler::Parser 0.31;
 class Tangence::Compiler::Parser :isa(Parser::MGC);
 
 use Syntax::Keyword::Dynamically;
@@ -69,7 +70,7 @@ The contents of the struct block will be a list of C<field> declarations.
 
 =cut
 
-has $_package;
+field $_package;
 
 # Parser::MGC version 0.20 adds this method. Before then, this workaround is
 # known to be safe
