@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2024 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.41;
+use warnings;
+use Object::Pad 0.800;
 
-package Tangence::Message 0.29;
+package Tangence::Message 0.31;
 class Tangence::Message;
 
 use Carp;
@@ -26,14 +27,25 @@ use Tangence::Object;
 use List::Util 1.29 qw( pairmap );
 use Scalar::Util qw( weaken blessed );
 
+=head1 NAME
+
+C<Tangence::Message> - contains a single C<Tangence> protocol message
+
+=head1 DESCRIPTION
+
+This module is a component of L<Tangence::Client> or L<Tangence::Server>. It
+is not intended for end-user use directly.
+
+=cut
+
 # Normally we don't care about hash key order. But, when writing test scripts
 # that will assert on the serialisation bytes, we do. Setting this to some
 # true value will sort keys first
 our $SORT_HASH_KEYS = 0;
 
-has $_stream  :param :reader;
-has $_code    :param :reader;
-has $_payload :param :reader;
+field $_stream  :param :reader;
+field $_code    :param :reader;
+field $_payload :param :reader;
 
 sub BUILDARGS ( $class, $stream, $code, $payload = "" )
 {
