@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2024 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.43;
+use warnings;
+use Object::Pad 0.800;
 
-package Tangence::Meta::Class 0.29;
+package Tangence::Meta::Class 0.31;
 class Tangence::Meta::Class :strict(params);
 
 use Carp;
@@ -34,13 +35,13 @@ Returns a new instance representing the given name.
 
 =cut
 
-has $name    :param :reader;
-has $defined        :reader = 0;
+field $name    :param :reader;
+field $defined        :reader = 0;
 
-has @superclasses;
-has %methods;
-has %events;
-has %properties;
+field @superclasses;
+field %methods;
+field %events;
+field %properties;
 
 =head2 define
 
