@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2024 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.51;
+use warnings;
+use Object::Pad 0.800 ':experimental(adjust_params)';
 
-package Tangence::Meta::Event 0.29;
+package Tangence::Meta::Event 0.31;
 class Tangence::Meta::Event :strict(params);
 
 =head1 NAME
@@ -49,14 +50,14 @@ L<Tangence::Meta::Argument> references.
 
 =cut
 
-has $class :param :weak :reader;
-has $name  :param       :reader;
-has @arguments;
+field $class :param :weak :reader;
+field $name  :param       :reader;
+field @arguments;
 
-ADJUSTPARAMS ( $params )
-{
-   exists $params->{arguments} and
-      @arguments = @{ delete $params->{arguments} };
+ADJUST :params (
+   :$arguments = undef,
+) {
+   @arguments = $arguments->@* if $arguments;
 }
 
 =head1 ACCESSORS
