@@ -1,18 +1,30 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2024 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.66;
+use warnings;
+use Object::Pad 0.800;
 
-package Tangence::Server::Context 0.30;
+package Tangence::Server::Context 0.31;
 class Tangence::Server::Context;
 
 use Carp;
 
 use Tangence::Constants;
 
+=head1 NAME
+
+C<Tangence::Server::Context> - server connection class for C<Tangence>
+
+=head1 DESCRIPTION
+
+This module is a component of L<Tangence::Server>. It is not intended for
+end-user use directly.
+
+=cut
+
 field $stream :param :reader;
 field $token  :param;
 
