@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2014 -- leonerd@leonerd.org.uk
 
-package Tangence::Types 0.29;
+package Tangence::Types 0.31;
 
 use v5.26;
 use warnings;
@@ -37,4 +37,21 @@ use constant TYPE_LIST_ANY => Tangence::Type->make( list => TYPE_ANY );
 
 use constant TYPE_DICT_ANY => Tangence::Type->make( dict => TYPE_ANY );
 
+=head1 NAME
+
+C<Tangence::Types> - type constants for C<Tangence>
+
+=head1 DESCRIPTION
+
+This module is a component of L<Tangence::Client> or L<Tangence::Server>. It
+is not intended for end-user use directly.
+
+=cut
+
+=head1 AUTHOR
+
+Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
 0x55AA;
